@@ -4,15 +4,21 @@ test_that("character variable", {
     mod <- glm(large_penguin ~ bill_length_mm + flipper_length_mm + species, data = dat, family = binomial)
     mfx <- marginaleffects(mod)
     tid <- tidy(mfx)
-    expect_true(all(c("bill_length_mm", "flipper_length_mm", "speciesChinstrap", "speciesGentoo") %in% mfx$term))
+    expect_true(all(c("bill_length_mm", "flipper_length_mm", "species") %in% mfx$term))
+    expect_true(all(c("Chinstrap - Adelie", "Gentoo - Adelie") %in% mfx$contrast))
 })
 
 
-test_that("missing character levels", {
+test_that("predictions: missing character levels", {
+    # get_predicted does not work here, but we successfully fall back on get_predict
     dat <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/palmerpenguins/penguins.csv")
     dat$large_penguin <- ifelse(dat$body_mass_g > median(dat$body_mass_g, na.rm = TRUE), 1, 0)
     mod <- glm(large_penguin ~ bill_length_mm + flipper_length_mm + species, data = dat, family = binomial)
-    mfx <- predictions(mod, newdata = typical(species = c("Chinstrap")))
-    expect_s3_class(mfx, "data.frame")
-    expect_equal(1, nrow(mfx))
+    # case 1
+    pred <- predictions(mod, newdata = datagrid(species = "Chinstrap"))
+    expect_s3_class(pred, "data.frame")
+    expect_equal(1, nrow(pred))
+    # case 2
+    pred <- predictions(mod, newdata = datagrid(species = c("Chinstrap", "Gentoo")))
+    expect_equal(nrow(pred), 2)
 })
