@@ -1,7 +1,3 @@
-skip_if_not_installed("margins")
-skip_if_not_installed("emmeans")
-skip_if_not_installed("dplyr")
-skip_if_not_installed("broom")
 requiet("margins")
 requiet("broom")
 requiet("emmeans")
@@ -23,6 +19,14 @@ test_that("glm: marginaleffects", {
     res <- marginaleffects(mod)
     mar <- margins(mod, unit_ses = TRUE)
     expect_true(test_against_margins(res, mar, tolerance = 0.1, verbose=TRUE))
+
+    # emmeans comparison
+    # type = "response" works at lower tolerance
+    em <- emmeans::emtrends(mod, ~x2, var = "x2", at = list(x1 = 0, x2 = 0, x3 = 0, x4 = 0))
+    em <- tidy(em)
+    mfx <- marginaleffects(mod, newdata = datagrid(x1 = 0, x2 = 0, x3 = 0, x4 = 0), variable = "x2", type = "link")
+    expect_equal(mfx$dydx, em$x2.trend)
+    expect_equal(mfx$std.error, em$std.error)
 })
 
 
@@ -30,11 +34,9 @@ test_that("glm vs. Stata: marginaleffects", {
     stata <- readRDS(test_path("stata/stata.rds"))[["stats_glm_01"]]
     dat <- read.csv(test_path("stata/databases/stats_glm_01.csv"))
     mod <- glm(y ~ x1 * x2, family = binomial, data = dat)
-    ame <- marginaleffects(mod) %>%
-           group_by(term) %>%
-           summarize(dydx = mean(dydx), std.error = mean(std.error)) %>%
-           inner_join(stata, by = "term")
-    expect_equal(ame$dydx, ame$dydxstata, tolerance = 0.00001)
+    ame <- merge(tidy(marginaleffects(mod)), stata)
+    expect_equal(ame$dydx, ame$dydxstata)
+    expect_equal(ame$std.error, ame$std.errorstata, tolerance = 0.0001)
 })
 
 
@@ -42,20 +44,31 @@ test_that("lm vs. Stata: marginaleffects", {
     stata <- readRDS(test_path("stata/stata.rds"))[["stats_lm_01"]]
     dat <- read.csv(test_path("stata/databases/stats_lm_01.csv"))
     mod <- lm(y ~ x1 * x2, data = dat)
-    ame <- marginaleffects(mod) %>%
-           group_by(term) %>%
-           summarize(dydx = mean(dydx), std.error = mean(std.error)) %>%
-           inner_join(stata, by = "term")
-    expect_equal(ame$dydx, ame$dydxstata, tolerance = 0.00001)
+    ame <- merge(tidy(marginaleffects(mod)), stata)
+    expect_equal(ame$dydx, ame$dydxstata)
+    expect_equal(ame$std.error, ame$std.errorstata)
 })
 
 
-test_that("lm with interactions vs. margins: marginaleffects", {
+test_that("lm with interactions vs. margins vs. emmeans: marginaleffects", {
     counterfactuals <- expand.grid(hp = 100, am = 0:1)
     mod <- lm(mpg ~ hp * am, data = mtcars)
     res <- marginaleffects(mod, variable = "hp", newdata = counterfactuals)
     mar <- margins(mod, variable = "hp", data = counterfactuals, unit_ses = TRUE)
     expect_true(test_against_margins(res, mar, tolerance = 1e-3))
+
+    # emmeans
+    void <- capture.output({
+        em1 <- emmeans::emtrends(mod, ~hp, var = "hp", at = list(hp = 100, am = 0))
+        em2 <- emmeans::emtrends(mod, ~hp, var = "hp", at = list(hp = 100, am = 1))
+        em1 <- tidy(em1)
+        em2 <- tidy(em2)
+    })
+    res <- marginaleffects(mod, variable = "hp", newdata = counterfactuals)
+    expect_equal(res$dydx[1], em1$hp.trend)
+    expect_equal(res$std.error[1], em1$std.error, tolerance = .001)
+    expect_equal(res$dydx[2], em2$hp.trend)
+    expect_equal(res$std.error[2], em2$std.error, tolerance = .0001)
 })
 
 
@@ -75,28 +88,36 @@ test_that("lm vs. emmeans: marginalmeans", {
 })
 
 
-test_that('glm vs. emmeans: marginalmeans(type = "link")', {
+test_that('glm: marginalmeans vs. emmeans', {
     # factors seem to behave differently in model.matrix
     skip_if(getRversion() == "3.6.3")
     dat <- guerry
     dat$binary <- dat$Crime_prop > median(dat$Crime_prop)
     # character variables sometimes break the order
     mod <- glm(binary ~ Region + MainCity + Commerce, data = dat, family = "binomial")
-    expect_error(marginalmeans(mod, type = "link"), regexp = "track of the reference category")
+
     # factor variables are safer
     dat$Region <- as.factor(dat$Region)
     dat$MainCity <- as.factor(dat$MainCity)
     mod <- glm(binary ~ Region + MainCity + Commerce, data = dat, family = "binomial")
+
     mm <- tidy(marginalmeans(mod, type = "link", variables = "Region"))
     em <- tidy(emmeans::emmeans(mod, specs = "Region"))
-    expect_equal(as.character(mm$group), em$Region)
+    expect_equal(as.character(mm$value), em$Region)
     expect_equal(mm$estimate, em$estimate)
     expect_equal(mm$std.error, em$std.error)
+
     mm <- tidy(marginalmeans(mod, type = "link", variables = "MainCity"))
     em <- tidy(emmeans::emmeans(mod, specs = "MainCity"))
-    expect_equal(as.character(mm$group), em$MainCity)
+    expect_equal(as.character(mm$value), em$MainCity)
     expect_equal(mm$estimate, em$estimate)
     expect_equal(mm$std.error, em$std.error)
+
+    mm <- tidy(marginalmeans(mod, type = "response", variables = "MainCity"))
+    em <- tidy(emmeans::emmeans(mod, specs = "MainCity", transform = "response"))
+    expect_equal(as.character(mm$value), em$MainCity)
+    expect_equal(mm$estimate, em$prob)
+    expect_equal(mm$std.error, em$std.error, tolerance = .0001)
 })
 
 
