@@ -24,7 +24,7 @@ test_that("summary: marginal means", {
     dat$vs <- as.logical(dat$vs)
     dat$gear <- as.factor(dat$gear)
     mod <- lm(mpg ~ gear + am + vs, dat)
-    me <- marginalmeans(mod)
-    s <- summary(me)
+    mm <- marginalmeans(mod)
+    s <- summary(mm)
     expect_snapshot(print(s))
 })
